==> pdapi-0.1.3-sources.jar: ml/pluto7073/pdapi/PDAPI.java <==
package ml.pluto7073.pdapi;

import ml.pluto7073.pdapi.addition.DrinkAdditions;
import ml.pluto7073.pdapi.block.PDBlocks;
import ml.pluto7073.pdapi.client.gui.PDScreens;
import ml.pluto7073.pdapi.entity.effect.PDStatusEffects;
import ml.pluto7073.pdapi.item.PDItems;
import ml.pluto7073.pdapi.listeners.DrinkAdditionRegisterer;
import ml.pluto7073.pdapi.recipes.PDRecipeTypes;
import net.fabricmc.api.ModInitializer;
import net.fabricmc.fabric.api.resource.ResourceManagerHelper;
import net.minecraft.class_2499;
import net.minecraft.class_2960;
import net.minecraft.class_3264;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class PDAPI implements ModInitializer {

    public static final String ID = "pdapi";
    public static final Logger LOGGER = LogManager.getLogger("PDAPI");

    @Override
    public void onInitialize() {
        PDRecipeTypes.init();
        PDBlocks.init();
        PDItems.init();
        PDStatusEffects.init();

        ResourceManagerHelper.get(class_3264.field_14190).registerReloadListener(new DrinkAdditionRegisterer());

        DrinkUtil.registerOldToNewConverter("Coffee/Additions", (DrinkUtil.Converter<class_2499>) list -> {
            if (list == null) return null;
            if (list.isEmpty()) return null;
            for (int i = 0; i < list.size(); i++) {
                class_2960 id = new class_2960(list.method_10608(i));
                boolean ogCoffee = !DrinkAdditions.containsId(id) && DrinkAdditions.containsId(PDAPI.asId(id.method_12832()));
                if (!ogCoffee) continue;
                id = PDAPI.asId(id.method_12832());
                list.method_10606(i, DrinkUtil.stringAsNbt(id.toString()));
            }
            return list;
        });

        PDScreens.init();

        LOGGER.info("Pluto's Drinks API ready!");
    }

    public static class_2960 asId(String name) {
        return new class_2960(ID, name);
    }

}

==> pdapi-0.1.4-sources.jar: ml/pluto7073/pdapi/PDAPI.java <==
package ml.pluto7073.pdapi;

import ml.pluto7073.pdapi.addition.DrinkAdditions;
import ml.pluto7073.pdapi.block.PDBlocks;
import ml.pluto7073.pdapi.client.gui.PDScreens;
import ml.pluto7073.pdapi.command.PDCommands;
import ml.pluto7073.pdapi.entity.effect.PDStatusEffects;
import ml.pluto7073.pdapi.gamerule.PDGameRules;
import ml.pluto7073.pdapi.item.PDItems;
import ml.pluto7073.pdapi.listeners.DrinkAdditionRegisterer;
import ml.pluto7073.pdapi.recipes.PDRecipeTypes;
import net.fabricmc.api.ModInitializer;
import net.fabricmc.fabric.api.resource.ResourceManagerHelper;
import net.minecraft.class_2499;
import net.minecraft.class_2960;
import net.minecraft.class_3264;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class PDAPI implements ModInitializer {

    public static final String ID = "pdapi";
    public static final Logger LOGGER = LogManager.getLogger("PDAPI");

    @Override
    public void onInitialize() {
        PDRecipeTypes.init();
        PDBlocks.init();
        PDItems.init();
        PDStatusEffects.init();
        PDGameRules.init();
        PDCommands.init();

        ResourceManagerHelper.get(class_3264.field_14190).registerReloadListener(new DrinkAdditionRegisterer());

        DrinkUtil.registerOldToNewConverter("Coffee/Additions", (DrinkUtil.Converter<class_2499>) list -> {
            if (list == null) return null;
            if (list.isEmpty()) return null;
            for (int i = 0; i < list.size(); i++) {
                class_2960 id = new class_2960(list.method_10608(i));
                boolean ogCoffee = !DrinkAdditions.containsId(id) && DrinkAdditions.containsId(PDAPI.asId(id.method_12832()));
                if (!ogCoffee) continue;
                id = PDAPI.asId(id.method_12832());
                list.method_10606(i, DrinkUtil.stringAsNbt(id.toString()));
            }
            return list;
        });

        PDScreens.init();

        LOGGER.info("Pluto's Drinks API ready!");
    }

    public static class_2960 asId(String name) {
        return new class_2960(ID, name);
    }

}
